#include "SQFuncs.h"
#include <stdio.h>
#include "Playerlist.h"
#include "WatchlistQuery.h"

extern SQAPI sq;
extern int auto_update_timer;
extern int last_forced_update;

#define COOLDOWN_PERIOD 21600000

_SQUIRRELDEF( CheckName )
{
	SQInteger iArgCount = sq->gettop( v );

	if ( iArgCount != 2 )
	{
		sq->pushbool( v, SQFalse );
		return 1;
	}

	const SQChar* szName;

	sq->getstring( v, 2, &szName );

	SQBool bResult = CPlayerListManager::CheckName( szName );

	sq->pushbool( v, bResult );
	return 1;
}

_SQUIRRELDEF( ForceUpdate )
{
	SQInteger iArgCount = sq->gettop( v );

	if ( iArgCount != 1 )
	{
		sq->pushbool( v, SQFalse );
		return 1;
	}

	int time = time_getticks();
	if ( (time - last_forced_update) >= COOLDOWN_PERIOD )
	{
		CWatchlist::Update();

		last_forced_update = time;

		sq->pushbool( v, SQTrue );

		return 1;
	}

	printf( "[WATCHLIST] Unable to force update watchlist, too many attempts in six hours.\n" );

	sq->pushbool( v, SQFalse );

	return 1;
	
}

_SQUIRRELDEF( SetUpdateInterval )
{
	SQInteger iArgCount = sq->gettop( v );

	if ( iArgCount != 2 )
	{
		sq->pushbool( v, SQFalse );
		return 1;
	}

	SQInteger iTime;

	sq->getinteger( v, 2, &iTime );

	if ( (int)iTime < COOLDOWN_PERIOD )
	{
		printf( "[WATCHLIST] Unable to set update interval, minimum time is 6 hours.\n" );
		sq->pushbool( v, SQFalse );
		return 1;
	}

	auto_update_timer = (int)iTime;

	sq->pushbool( v, SQTrue );

	return 1;
}

SQInteger RegisterSquirrelFunc( HSQUIRRELVM v, SQFUNCTION f, const SQChar* fname, unsigned char ucParams, const SQChar* szParams )
{
	char szNewParams[ 32 ];

	sq->pushroottable( v );
	sq->pushstring( v, fname, -1 );
	sq->newclosure( v, f, 0 ); /* create a new function */

	if ( ucParams > 0 ) 
	{
		ucParams++; /* This is to compensate for the root table */
		
		sprintf( szNewParams, "t%s", szParams );

		sq->setparamscheck( v, ucParams, szNewParams ); /* Add a param type check */
	}

	sq->setnativeclosurename( v, -1, fname );
	sq->newslot( v, -3, SQFalse );
	sq->pop( v, 1 ); /* pops the root table */

	return 0;
}

void RegisterFuncs( HSQUIRRELVM v )
{
	/* Add your Squirrel functions here */

	RegisterSquirrelFunc( v, CheckName, "Watchlist_CheckName", 1, "s" );
	RegisterSquirrelFunc( v, ForceUpdate, "Watchlist_ForceUpdate", 0, 0 );
	RegisterSquirrelFunc( v, SetUpdateInterval, "Watchlist_SetUpdateInterval", 1, "i" );
}
