#include "SQMain.h"
#include "SQFuncs.h"
#include <stdio.h>
#ifdef _WIN32
#include <WinSock2.h>
#endif

#include "WatchlistQuery.h"

SQAPI sq;

int last_update = 0;
int auto_update_timer = 21600000; // This is 6 hours in ticks (1 second = 1000 ticks)
int last_forced_update = 0; // When the update was last forced.

/*
 * SQLoad() is called when the script requests loading this module. This is where module
 * initialization and native function/constant registering is done.
 */
LU_EXPORT SQRESULT SQLoad( HSQUIRRELVM v, SQAPI api )
{
	sq = api;

	RegisterFuncs( v );

	printf( "\n[WATCHLIST] Global watchlist module loaded.\n" );

#ifdef _WIN32
	WSADATA wsaData;
	if ( WSAStartup( MAKEWORD( 2, 2 ), &wsaData ) != 0 )
	{
		printf( "\n[WATCHLIST] Failed to initialise WinSock" );
		return SQ_OK;
	}
#endif

	CWatchlist::Update();

	last_update = time_getticks();

	return SQ_OK;
}

/*
 * SQUnload() gets called when a script calls UnloadModule() or the script using this module
 * is being unloaded. Usually nothing is required to do here, if the module allocates memory
 * for its own usage this memory should be freed.
 */
LU_EXPORT SQRESULT SQUnload( void )
{
	CPlayerListManager::RemoveAll();

	return SQ_OK;
}

/*
 * SQCallback is reserved for possible future callbacks.
 * For a list of callbacks, check enum eSquirrelCallback in SQModule.h
 */
LU_EXPORT SQRESULT SQCallback( unsigned int uiCallback, void* pData )
{
	return SQ_OK;
}

/*
 * SQPulse() is a function which gets called on every server cycle.
 */
LU_EXPORT SQRESULT SQPulse( void )
{
	// If the time to update has passed then we need to update the watchlist and reset the timer.
	int time = time_getticks();
	if ( (time - last_update) >= auto_update_timer )
	{
		CWatchlist::Update();
		last_update = time_getticks();
	}

	return SQ_OK;
}

unsigned int time_getticks( void )
{
	#if defined( _WIN32 ) || defined( _WIN64 )
		return GetTickCount();
	#else
		struct timespec now;
		clock_gettime( CLOCK_MONOTONIC, &now );
		return (unsigned int)( (now.tv_sec * 1000000000LL + now.tv_nsec ) / 1000000LL );
	#endif
}